var searchData=
[
  ['chip_5ferase_5f1_0',['CHIP_ERASE_1',['../s25fl1_8h.html#a31b64c3b01f5cdc3808e448353fce355',1,'s25fl1.h']]],
  ['chip_5ferase_5f2_1',['CHIP_ERASE_2',['../s25fl1_8h.html#ae600f76846f336b676ac0377a44b83a0',1,'s25fl1.h']]],
  ['chip_5fusb_5fdma_5fnumpipe_2',['CHIP_USB_DMA_NUMPIPE',['../usbhs_8h.html#a1e17be7a8b9f3a7fa532293e5a776fed',1,'usbhs.h']]],
  ['chip_5fusb_5fendpoints_5fbanks_3',['CHIP_USB_ENDPOINTS_BANKS',['../usbhs_8h.html#ab66857dec68cedaa0b3d3008296ffd97',1,'usbhs.h']]],
  ['chip_5fusb_5fendpoints_5fdma_4',['CHIP_USB_ENDPOINTS_DMA',['../usbhs_8h.html#a3d3e0780955f1f3796b59c297a9ce778',1,'usbhs.h']]],
  ['chip_5fusb_5fendpoints_5fmaxpacketsize_5',['CHIP_USB_ENDPOINTS_MAXPACKETSIZE',['../usbhs_8h.html#a5865e5e766958f78b10bee61f42abd44',1,'usbhs.h']]],
  ['chip_5fusb_5fnumendpoints_6',['CHIP_USB_NUMENDPOINTS',['../usbhs_8h.html#ab1098bd73746d6f0b0ab28975d2a5043',1,'usbhs.h']]],
  ['chip_5fusb_5fnumpipe_7',['CHIP_USB_NUMPIPE',['../usbhs_8h.html#a8f0b960f10c286e7cd0e0b736aa1e4db',1,'usbhs.h']]],
  ['chip_5fusb_5fpipe_5fbanks_8',['CHIP_USB_PIPE_BANKS',['../usbhs_8h.html#a0dd7d33f558f878925c4aa8f2f6dc96d',1,'usbhs.h']]],
  ['chip_5fusb_5fpipe_5fdma_9',['CHIP_USB_PIPE_DMA',['../usbhs_8h.html#a375cc1a475941bb356f59c53aae6c951',1,'usbhs.h']]],
  ['chip_5fusb_5fpipe_5fmaxpacketsize_10',['CHIP_USB_PIPE_MAXPACKETSIZE',['../usbhs_8h.html#a7d5ac656db4059a4b765bf4e239d8fe5',1,'usbhs.h']]],
  ['chip_5fusb_5fpullup_5finternal_11',['CHIP_USB_PULLUP_INTERNAL',['../usbhs_8h.html#a4bcc957f1288dac54003f5a0045b2cd7',1,'usbhs.h']]],
  ['chip_5fusb_5fudp_12',['CHIP_USB_UDP',['../usbhs_8h.html#a0d5301f4b6b7c4dc59bdd76d725c9517',1,'usbhs.h']]],
  ['clock_5fdriver_5fsupport_5fat_5ftick_13',['Clock_driver_support_at_tick',['../bsps_2shared_2dev_2clock_2clockimpl_8h.html#a8e307eb7ef98fa3414d308f963a8fe92',1,'clockimpl.h']]],
  ['clock_5fdriver_5fsupport_5ffind_5ftimer_14',['Clock_driver_support_find_timer',['../bsps_2shared_2dev_2clock_2clockimpl_8h.html#a298b82337f8f3d7e33181569c1bfddd5',1,'clockimpl.h']]],
  ['clock_5fdriver_5fsupport_5finstall_5fisr_15',['Clock_driver_support_install_isr',['../bsps_2shared_2dev_2clock_2clockimpl_8h.html#a9ceaea4d5c663943f1ee7da161c0c52e',1,'clockimpl.h']]],
  ['clock_5fdriver_5fsupport_5fset_5finterrupt_5faffinity_16',['Clock_driver_support_set_interrupt_affinity',['../bsps_2shared_2dev_2clock_2clockimpl_8h.html#a6d50e63577472e1a7899c19f75dc54b8',1,'clockimpl.h']]],
  ['console_5fbaudrate_17',['CONSOLE_BAUDRATE',['../dbg__console_8c.html#a40ffb962a11e58bd992ccc415974537e',1,'dbg_console.c']]],
  ['console_5fdevice_5fname_18',['CONSOLE_DEVICE_NAME',['../cpukit_2include_2rtems_2console_8h.html#a94b335670671f1e5ccdc9c98a5a504f7',1,'console.h']]],
  ['console_5fdriver_5ftable_5fentry_19',['CONSOLE_DRIVER_TABLE_ENTRY',['../cpukit_2include_2rtems_2console_8h.html#a161ccfcc3b45dbeaba758807eef66a3a',1,'console.h']]],
  ['console_5fedbg_20',['CONSOLE_EDBG',['../dbg__console_8c.html#ad98c0bea33fa991e587ba92d3d9b4bb1',1,'dbg_console.c']]],
  ['console_5fpins_21',['CONSOLE_PINS',['../dbg__console_8c.html#a531b67bfef5cbfd8ca9ec940af2796dc',1,'dbg_console.c']]],
  ['console_5fusart_22',['CONSOLE_Usart',['../dbg__console_8c.html#ac17d25afedece4eb724baa90a0e415ff',1,'dbg_console.c']]],
  ['cont_5fmode_5freset_23',['CONT_MODE_RESET',['../s25fl1_8h.html#af7eda36acbc4b9da6fd7700501b9d65d',1,'s25fl1.h']]],
  ['cpu_5falignment_24',['CPU_ALIGNMENT',['../bfin_2include_2rtems_2score_2cpu_8h.html#ae526a309e32001688261048b19cdb7d8',1,'CPU_ALIGNMENT():&#160;cpu.h'],['../lm32_2include_2rtems_2score_2cpu_8h.html#ae526a309e32001688261048b19cdb7d8',1,'CPU_ALIGNMENT():&#160;cpu.h'],['../no__cpu_2include_2rtems_2score_2cpu_8h.html#ae526a309e32001688261048b19cdb7d8',1,'CPU_ALIGNMENT():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#ae526a309e32001688261048b19cdb7d8',1,'CPU_ALIGNMENT():&#160;cpu.h'],['../v850_2include_2rtems_2score_2cpu_8h.html#ae526a309e32001688261048b19cdb7d8',1,'CPU_ALIGNMENT():&#160;cpu.h']]],
  ['cpu_5fall_5ftasks_5fare_5ffp_25',['CPU_ALL_TASKS_ARE_FP',['../lm32_2include_2rtems_2score_2cpu_8h.html#a225de03a8647bf307a73cf907969778d',1,'CPU_ALL_TASKS_ARE_FP():&#160;cpu.h'],['../no__cpu_2include_2rtems_2score_2cpu_8h.html#a225de03a8647bf307a73cf907969778d',1,'CPU_ALL_TASKS_ARE_FP():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#a225de03a8647bf307a73cf907969778d',1,'CPU_ALL_TASKS_ARE_FP():&#160;cpu.h']]],
  ['cpu_5fcache_5fline_5fbytes_26',['CPU_CACHE_LINE_BYTES',['../microblaze_2include_2rtems_2score_2cpu_8h.html#aafa1399e268a9ae6adf6d6aad4371688',1,'CPU_CACHE_LINE_BYTES():&#160;cpu.h'],['../no__cpu_2include_2rtems_2score_2cpu_8h.html#aafa1399e268a9ae6adf6d6aad4371688',1,'CPU_CACHE_LINE_BYTES():&#160;cpu.h']]],
  ['cpu_5fcontext_5ffp_5fsize_27',['CPU_CONTEXT_FP_SIZE',['../sparc_2include_2rtems_2score_2cpu_8h.html#af58e4ff1f7e1c85fc5c0b80cbd0672c5',1,'cpu.h']]],
  ['cpu_5fenable_5frobust_5fthread_5fdispatch_28',['CPU_ENABLE_ROBUST_THREAD_DISPATCH',['../no__cpu_2include_2rtems_2score_2cpu_8h.html#a0c634f4a6bc9236bcacafc9b6119e011',1,'cpu.h']]],
  ['cpu_5fhardware_5ffp_29',['CPU_HARDWARE_FP',['../no__cpu_2include_2rtems_2score_2cpu_8h.html#a112f88f13afe8bb8f1b13f1ca7e09b8d',1,'CPU_HARDWARE_FP():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#a112f88f13afe8bb8f1b13f1ca7e09b8d',1,'CPU_HARDWARE_FP():&#160;cpu.h']]],
  ['cpu_5fheap_5falignment_30',['CPU_HEAP_ALIGNMENT',['../bfin_2include_2rtems_2score_2cpu_8h.html#ac71c1e0159c32144a04f18646ede252b',1,'CPU_HEAP_ALIGNMENT():&#160;cpu.h'],['../lm32_2include_2rtems_2score_2cpu_8h.html#ac71c1e0159c32144a04f18646ede252b',1,'CPU_HEAP_ALIGNMENT():&#160;cpu.h'],['../no__cpu_2include_2rtems_2score_2cpu_8h.html#ac71c1e0159c32144a04f18646ede252b',1,'CPU_HEAP_ALIGNMENT():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#ac71c1e0159c32144a04f18646ede252b',1,'CPU_HEAP_ALIGNMENT():&#160;cpu.h'],['../v850_2include_2rtems_2score_2cpu_8h.html#ac71c1e0159c32144a04f18646ede252b',1,'CPU_HEAP_ALIGNMENT():&#160;cpu.h']]],
  ['cpu_5fidle_5ftask_5fis_5ffp_31',['CPU_IDLE_TASK_IS_FP',['../lm32_2include_2rtems_2score_2cpu_8h.html#af1c906c8ee4c3d012dc456285e42d3ee',1,'CPU_IDLE_TASK_IS_FP():&#160;cpu.h'],['../no__cpu_2include_2rtems_2score_2cpu_8h.html#af1c906c8ee4c3d012dc456285e42d3ee',1,'CPU_IDLE_TASK_IS_FP():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#af1c906c8ee4c3d012dc456285e42d3ee',1,'CPU_IDLE_TASK_IS_FP():&#160;cpu.h']]],
  ['cpu_5finterrupt_5fmaximum_5fvector_5fnumber_32',['CPU_INTERRUPT_MAXIMUM_VECTOR_NUMBER',['../microblaze_2include_2rtems_2score_2cpu_8h.html#a3c2363ae6ca6575fc9147b1b7585b3b4',1,'CPU_INTERRUPT_MAXIMUM_VECTOR_NUMBER():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#a3c2363ae6ca6575fc9147b1b7585b3b4',1,'CPU_INTERRUPT_MAXIMUM_VECTOR_NUMBER():&#160;cpu.h']]],
  ['cpu_5finterrupt_5fnumber_5fof_5fvectors_33',['CPU_INTERRUPT_NUMBER_OF_VECTORS',['../sparc_2include_2rtems_2score_2cpu_8h.html#a937007b12441849696a0462fee2b8d3e',1,'cpu.h']]],
  ['cpu_5finterrupt_5fstack_5falignment_34',['CPU_INTERRUPT_STACK_ALIGNMENT',['../no__cpu_2include_2rtems_2score_2cpu_8h.html#a6a578627686e1020a28f5a295703ca74',1,'cpu.h']]],
  ['cpu_5fisr_5fpasses_5fframe_5fpointer_35',['CPU_ISR_PASSES_FRAME_POINTER',['../bfin_2include_2rtems_2score_2cpu_8h.html#a30c4d320f85b1383c5059da5b19b164a',1,'CPU_ISR_PASSES_FRAME_POINTER():&#160;cpu.h'],['../lm32_2include_2rtems_2score_2cpu_8h.html#a30c4d320f85b1383c5059da5b19b164a',1,'CPU_ISR_PASSES_FRAME_POINTER():&#160;cpu.h'],['../no__cpu_2include_2rtems_2score_2cpu_8h.html#a30c4d320f85b1383c5059da5b19b164a',1,'CPU_ISR_PASSES_FRAME_POINTER():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#a30c4d320f85b1383c5059da5b19b164a',1,'CPU_ISR_PASSES_FRAME_POINTER():&#160;cpu.h']]],
  ['cpu_5fmaximum_5fprocessors_36',['CPU_MAXIMUM_PROCESSORS',['../no__cpu_2include_2rtems_2score_2cpu_8h.html#adea68a7fa02909edcebee08748f94223',1,'cpu.h']]],
  ['cpu_5fmodel_5fname_37',['CPU_MODEL_NAME',['../sparc_8h.html#a6161655f251417659ec80a3023bb0ec9',1,'sparc.h']]],
  ['cpu_5fmodes_5finterrupt_5fmask_38',['CPU_MODES_INTERRUPT_MASK',['../sparc_2include_2rtems_2score_2cpu_8h.html#af8823e651e33b9683e0d89e5a8054ee6',1,'cpu.h']]],
  ['cpu_5fmpci_5freceive_5fserver_5fextra_5fstack_39',['CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK',['../no__cpu_2include_2rtems_2score_2cpu_8h.html#ab94869be93a41da88a10fa59771ce2c9',1,'CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#ab94869be93a41da88a10fa59771ce2c9',1,'CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK():&#160;cpu.h']]],
  ['cpu_5fname_40',['CPU_NAME',['../sparc_8h.html#a65a2f3e765349445fd8ad6a44d7e498a',1,'sparc.h']]],
  ['cpu_5fprovides_5fisr_5fis_5fin_5fprogress_41',['CPU_PROVIDES_ISR_IS_IN_PROGRESS',['../sparc_2include_2rtems_2score_2cpu_8h.html#a47f6e4d60c72b5f65fc775b0b5dd14ec',1,'cpu.h']]],
  ['cpu_5fsimple_5fvectored_5finterrupts_42',['CPU_SIMPLE_VECTORED_INTERRUPTS',['../lm32_2include_2rtems_2score_2cpu_8h.html#a1eca01dbb1ef2873349cc4e222509f0a',1,'CPU_SIMPLE_VECTORED_INTERRUPTS():&#160;cpu.h'],['../no__cpu_2include_2rtems_2score_2cpu_8h.html#a1eca01dbb1ef2873349cc4e222509f0a',1,'CPU_SIMPLE_VECTORED_INTERRUPTS():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#a1eca01dbb1ef2873349cc4e222509f0a',1,'CPU_SIMPLE_VECTORED_INTERRUPTS():&#160;cpu.h'],['../v850_2include_2rtems_2score_2cpu_8h.html#a1eca01dbb1ef2873349cc4e222509f0a',1,'CPU_SIMPLE_VECTORED_INTERRUPTS():&#160;cpu.h']]],
  ['cpu_5fsizeof_5fpointer_43',['CPU_SIZEOF_POINTER',['../moxie_2include_2rtems_2score_2cpu_8h.html#aea4bd2905092d69bc92fbff6103ced8b',1,'CPU_SIZEOF_POINTER():&#160;cpu.h'],['../no__cpu_2include_2rtems_2score_2cpu_8h.html#aea4bd2905092d69bc92fbff6103ced8b',1,'CPU_SIZEOF_POINTER():&#160;cpu.h'],['../or1k_2include_2rtems_2score_2cpu_8h.html#aea4bd2905092d69bc92fbff6103ced8b',1,'CPU_SIZEOF_POINTER():&#160;cpu.h'],['../or1k_2include_2rtems_2score_2cpu_8h.html#aea4bd2905092d69bc92fbff6103ced8b',1,'CPU_SIZEOF_POINTER():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#aea4bd2905092d69bc92fbff6103ced8b',1,'CPU_SIZEOF_POINTER():&#160;cpu.h']]],
  ['cpu_5fsoftware_5ffp_44',['CPU_SOFTWARE_FP',['../no__cpu_2include_2rtems_2score_2cpu_8h.html#a304f78c61edce38bb88e909f90a326dc',1,'CPU_SOFTWARE_FP():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#a304f78c61edce38bb88e909f90a326dc',1,'CPU_SOFTWARE_FP():&#160;cpu.h']]],
  ['cpu_5fstack_5falignment_45',['CPU_STACK_ALIGNMENT',['../no__cpu_2include_2rtems_2score_2cpu_8h.html#a8aed43eb1b3c346772c127482b4b5372',1,'CPU_STACK_ALIGNMENT():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#a8aed43eb1b3c346772c127482b4b5372',1,'CPU_STACK_ALIGNMENT():&#160;cpu.h'],['../v850_2include_2rtems_2score_2cpu_8h.html#a8aed43eb1b3c346772c127482b4b5372',1,'CPU_STACK_ALIGNMENT():&#160;cpu.h']]],
  ['cpu_5fstack_5fframe_5fi0_5foffset_46',['CPU_STACK_FRAME_I0_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a83e4c35c5ed6801e9fe865fa0e0083fb',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fi1_5foffset_47',['CPU_STACK_FRAME_I1_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#ab62b81366df72b65984d34c6b1e6b632',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fi2_5foffset_48',['CPU_STACK_FRAME_I2_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a1daf51a3417acc33bdc9bd26bd1f6e22',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fi3_5foffset_49',['CPU_STACK_FRAME_I3_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a37af459858e70e9bad53ef8fa15cf904',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fi4_5foffset_50',['CPU_STACK_FRAME_I4_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a3633f9b64501f0d4f47bc0caa6de3d3d',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fi5_5foffset_51',['CPU_STACK_FRAME_I5_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a0be5e3d1ca73080dd038623dbed8f687',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fi6_5ffp_5foffset_52',['CPU_STACK_FRAME_I6_FP_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a930d5f24902abf5f300f0e97aa4cdeaf',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fi7_5foffset_53',['CPU_STACK_FRAME_I7_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a21c680e8b657f5dbfbe9377e24c3fb74',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fl0_5foffset_54',['CPU_STACK_FRAME_L0_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a575f62ed7aed84f7552ec3ef1bf6a7bb',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fl1_5foffset_55',['CPU_STACK_FRAME_L1_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#aa6eb407b793bb7907dcaa32f94c519b3',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fl2_5foffset_56',['CPU_STACK_FRAME_L2_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#aa30adc37edabd087be7e9a0a6df51514',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fl3_5foffset_57',['CPU_STACK_FRAME_L3_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a81bd26d0f67f142516b6f9050d167787',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fl4_5foffset_58',['CPU_STACK_FRAME_L4_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#af2cbaf050a7a90a2e1f193c3f13cd7e7',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fl5_5foffset_59',['CPU_STACK_FRAME_L5_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#aa75cc6154a548abc54be904726f06193',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fl6_5foffset_60',['CPU_STACK_FRAME_L6_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#af86368584fed0f70f4ea2928c9849531',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fl7_5foffset_61',['CPU_STACK_FRAME_L7_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a8cf7d947f0bdb16ba4490c328efae48f',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fpad0_5foffset_62',['CPU_STACK_FRAME_PAD0_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#aa09f0e7e0b5f905bd0dbcd5901b4f07f',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fsaved_5farg0_5foffset_63',['CPU_STACK_FRAME_SAVED_ARG0_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a083d79bd687c3712c74f96e5db95f81a',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fsaved_5farg1_5foffset_64',['CPU_STACK_FRAME_SAVED_ARG1_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a3b8b755c656e8fdebfa133c5c3f5871d',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fsaved_5farg2_5foffset_65',['CPU_STACK_FRAME_SAVED_ARG2_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#ae32ed54740ae621cc8cfb50704bf4cf4',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fsaved_5farg3_5foffset_66',['CPU_STACK_FRAME_SAVED_ARG3_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a42b2ded2c750923f0212593e30328507',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fsaved_5farg4_5foffset_67',['CPU_STACK_FRAME_SAVED_ARG4_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a2edd72af2496a05109268c607c07db15',1,'cpu.h']]],
  ['cpu_5fstack_5fframe_5fsaved_5farg5_5foffset_68',['CPU_STACK_FRAME_SAVED_ARG5_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a92993a124a97f17a5a4794fd4c0424f4',1,'cpu.h']]],
  ['cpu_5fstack_5fgrows_5fup_69',['CPU_STACK_GROWS_UP',['../bfin_2include_2rtems_2score_2cpu_8h.html#ac40d98a563f63934a5775f1366ba1b67',1,'CPU_STACK_GROWS_UP():&#160;cpu.h'],['../lm32_2include_2rtems_2score_2cpu_8h.html#ac40d98a563f63934a5775f1366ba1b67',1,'CPU_STACK_GROWS_UP():&#160;cpu.h'],['../no__cpu_2include_2rtems_2score_2cpu_8h.html#ac40d98a563f63934a5775f1366ba1b67',1,'CPU_STACK_GROWS_UP():&#160;cpu.h'],['../sparc_2include_2rtems_2score_2cpu_8h.html#ac40d98a563f63934a5775f1366ba1b67',1,'CPU_STACK_GROWS_UP():&#160;cpu.h'],['../v850_2include_2rtems_2score_2cpu_8h.html#ac40d98a563f63934a5775f1366ba1b67',1,'CPU_STACK_GROWS_UP():&#160;cpu.h']]],
  ['cpu_5fstack_5fminimum_5fsize_70',['CPU_STACK_MINIMUM_SIZE',['../sparc_2include_2rtems_2score_2cpu_8h.html#a4c92ceea7549cc7b21db2c466916b733',1,'cpu.h']]],
  ['cpu_5fstructure_5falignment_71',['CPU_STRUCTURE_ALIGNMENT',['../no__cpu_2include_2rtems_2score_2cpu_8h.html#acd43704c7821a2c042d212801156584e',1,'cpu.h']]],
  ['cpu_5fstructure_5freturn_5faddress_5foffset_72',['CPU_STRUCTURE_RETURN_ADDRESS_OFFSET',['../sparc_2include_2rtems_2score_2cpu_8h.html#a308a86e7d62e608b0f2b5595cd0fdc6e',1,'cpu.h']]],
  ['cpu_5fswap_5fu16_73',['CPU_swap_u16',['../sparc_2include_2rtems_2score_2cpu_8h.html#a1936ecb0107e5875a7b538374c1f621d',1,'cpu.h']]],
  ['cpu_5fuse_5fdeferred_5ffp_5fswitch_74',['CPU_USE_DEFERRED_FP_SWITCH',['../lm32_2include_2rtems_2score_2cpu_8h.html#a155bcf88149016c6c58f30eeab9f1598',1,'CPU_USE_DEFERRED_FP_SWITCH():&#160;cpu.h'],['../no__cpu_2include_2rtems_2score_2cpu_8h.html#a155bcf88149016c6c58f30eeab9f1598',1,'CPU_USE_DEFERRED_FP_SWITCH():&#160;cpu.h']]],
  ['cpu_5fuse_5fgeneric_5fbitfield_5fcode_75',['CPU_USE_GENERIC_BITFIELD_CODE',['../sparc_2include_2rtems_2score_2cpu_8h.html#ab0aff7a561b9c030a4d88eff201f4688',1,'cpu.h']]],
  ['cpu_5fuse_5flibc_5finit_5ffini_5farray_76',['CPU_USE_LIBC_INIT_FINI_ARRAY',['../no__cpu_2include_2rtems_2score_2cpu_8h.html#adf092511ce9c80c5e43bce3b1950d29d',1,'cpu.h']]],
  ['cs2100_5freg_5f32_5fbit_5fratio_5f1_77',['CS2100_REG_32_BIT_RATIO_1',['../cs2100_8h.html#a8ed061460d678ebb52195ff05e61b7de',1,'cs2100.h']]],
  ['cs2100_5freg_5f32_5fbit_5fratio_5f2_78',['CS2100_REG_32_BIT_RATIO_2',['../cs2100_8h.html#a0f7105b3674a15a11e8de294aec712ef',1,'cs2100.h']]],
  ['cs2100_5freg_5f32_5fbit_5fratio_5f3_79',['CS2100_REG_32_BIT_RATIO_3',['../cs2100_8h.html#aa7b6194d821364d7c78873cd2fbfa779',1,'cs2100.h']]],
  ['cs2100_5freg_5f32_5fbit_5fratio_5f4_80',['CS2100_REG_32_BIT_RATIO_4',['../cs2100_8h.html#a97b7c077a082ff81a6a5d0cd2d7bf3e9',1,'cs2100.h']]],
  ['cs2100_5freg_5fcfg_81',['CS2100_REG_CFG',['../cs2100_8h.html#ad6b82529348482375653dcc074716efb',1,'cs2100.h']]],
  ['cs2100_5freg_5fctrl_82',['CS2100_REG_CTRL',['../cs2100_8h.html#a9917667a3c999f0ca40bf24673f5cf6c',1,'cs2100.h']]],
  ['cs2100_5freg_5fdev_5fcfg1_83',['CS2100_REG_DEV_CFG1',['../cs2100_8h.html#a89147f648bf87ac944ef3b08430fdcb8',1,'cs2100.h']]],
  ['cs2100_5freg_5ffunc_5fcfg1_84',['CS2100_REG_FUNC_CFG1',['../cs2100_8h.html#adc318e54a9a152efa75ee467cbf612c8',1,'cs2100.h']]],
  ['cs2100_5freg_5ffunc_5fcfg2_85',['CS2100_REG_FUNC_CFG2',['../cs2100_8h.html#a7b5df9431eecfea136eb1cb182bcf658',1,'cs2100.h']]],
  ['cs2100_5freg_5ffunc_5fcfg3_86',['CS2100_REG_FUNC_CFG3',['../cs2100_8h.html#a8dfbebc245e52d178a723195d3700b60',1,'cs2100.h']]],
  ['cs2100_5freg_5fid_87',['CS2100_REG_ID',['../cs2100_8h.html#a2d68d11f57f1fb42d3d3d1b25f97813a',1,'cs2100.h']]],
  ['csi_5fvalue_88',['CSI_VALUE',['../stm32h7xx__hal__conf__template_8h.html#a4dcbff36a4b1cfd045c01d59084255d0',1,'stm32h7xx_hal_conf_template.h']]]
];
